(sec_citation)=

# Citing msprime

If you use `msprime` in your work, please cite the
[2016 PLOS Computational Biology paper](<http://dx.doi.org/10.1371/journal.pcbi.1004842>):

> Jerome Kelleher, Alison M Etheridge and Gilean McVean (2016),
> *Efficient Coalescent Simulation and Genealogical Analysis for Large Sample Sizes*,
> PLOS Comput Biol 12(5): e1004842. doi: 10.1371/journal.pcbi.1004842

Additionally, if you use the Discrete Time Wright Fisher model, please cite the
[2020 PLOS Genetics paper](https://doi.org/10.1371/journal.pgen.1008619):

> Dominic Nelson, Jerome Kelleher, Aaron P. Ragsdale, Claudia Moreau,
> Gil McVean and Simon Gravel (2020),
> *Accounting for long-range correlations in genome-wide simulations of large cohorts*,
> PLOS Genetics 16(5): e1008619. https://doi.org/10.1371/journal.pgen.1008619

Bibtex records:

```bibtex
@article{kelleher2016efficient,
  title={Efficient coalescent simulation and genealogical analysis for large sample sizes},
  author={Kelleher, Jerome and Etheridge, Alison M and McVean, Gilean},
  journal={PLoS computational biology},
  volume={12},
  number={5},
  pages={e1004842},
  year={2016},
  publisher={Public Library of Science}
}

@article{nelson2020accounting,
  title={Accounting for long-range correlations in genome-wide simulations of large cohorts},
  author={Nelson, Dominic and Kelleher, Jerome and Ragsdale, Aaron P and
    Moreau, Claudia and McVean, Gil and Gravel, Simon},
  journal={PLoS genetics},
  volume={16},
  number={5},
  pages={e1008619},
  year={2020},
  publisher={Public Library of Science}
}
```
